pub struct GoogleCloudChannelV1ChangeOfferRequest {
pub billing_account: Option<String>,
pub offer: Option<String>,
pub parameters: Option<Vec<GoogleCloudChannelV1Parameter>>,
pub price_reference_id: Option<String>,
pub purchase_order_id: Option<String>,
pub request_id: Option<String>,
}Expand description
Request message for CloudChannelService.ChangeOffer.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
billing_account: Option<String>Optional. The billing account resource name that is used to pay for this entitlement when setting up billing on a trial subscription. This field is only relevant for multi-currency accounts. It should be left empty for single currency accounts.
offer: Option<String>Required. New Offer. Format: accounts/{account_id}/offers/{offer_id}.
parameters: Option<Vec<GoogleCloudChannelV1Parameter>>Optional. Parameters needed to purchase the Offer. To view the available Parameters refer to the Offer.parameter_definitions from the desired offer.
price_reference_id: Option<String>Optional. Price reference ID for the offer. Only for offers that require additional price information. Used to guarantee that the pricing is consistent between quoting the offer and placing the order.
purchase_order_id: Option<String>Optional. Purchase order id provided by the reseller.
request_id: Option<String>Optional. You can specify an optional unique request ID, and if you need to retry your request, the server will know to ignore the request if it’s complete. For example, you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if it received the original operation with the same request ID. If it did, it will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).