GoogleCloudChannelV1ChannelPartnerRepricingConfig

Struct GoogleCloudChannelV1ChannelPartnerRepricingConfig 

pub struct GoogleCloudChannelV1ChannelPartnerRepricingConfig {
    pub name: Option<String>,
    pub repricing_config: Option<GoogleCloudChannelV1RepricingConfig>,
    pub update_time: Option<DateTime<Utc>>,
}
Configuration for how a distributor will rebill a channel partner (also known as a distributor-authorized reseller).

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

name: Option<String>

Output only. Resource name of the ChannelPartnerRepricingConfig. Format: accounts/{account_id}/channelPartnerLinks/{channel_partner_id}/channelPartnerRepricingConfigs/{id}.

repricing_config: Option<GoogleCloudChannelV1RepricingConfig>

Required. The configuration for bill modifications made by a reseller before sending it to ChannelPartner.

update_time: Option<DateTime<Utc>>

Output only. Timestamp of an update to the repricing rule. If update_time is after RepricingConfig.effective_invoice_month then it indicates this was set mid-month.