GoogleCloudChannelV1ImportCustomerRequest

Struct GoogleCloudChannelV1ImportCustomerRequest 

pub struct GoogleCloudChannelV1ImportCustomerRequest {
    pub auth_token: Option<String>,
    pub channel_partner_id: Option<String>,
    pub cloud_identity_id: Option<String>,
    pub customer: Option<String>,
    pub domain: Option<String>,
    pub overwrite_if_exists: Option<bool>,
    pub primary_admin_email: Option<String>,
}
Request message for CloudChannelService.ImportCustomer

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

auth_token: Option<String>

Optional. The super admin of the resold customer generates this token to authorize a reseller to access their Cloud Identity and purchase entitlements on their behalf. You can omit this token after authorization. See https://support.google.com/a/answer/7643790 for more details.

channel_partner_id: Option<String>

Optional. Cloud Identity ID of a channel partner who will be the direct reseller for the customer’s order. This field is required for 2-tier transfer scenarios and can be provided via the request Parent binding as well.

cloud_identity_id: Option<String>

Required. Customer’s Cloud Identity ID

customer: Option<String>

Optional. Specifies the customer that will receive imported Cloud Identity information. Format: accounts/{account_id}/customers/{customer_id}

domain: Option<String>

Required. Customer domain.

overwrite_if_exists: Option<bool>

Required. Choose to overwrite an existing customer if found. This must be set to true if there is an existing customer with a conflicting region code or domain.

primary_admin_email: Option<String>

Required. Customer’s primary admin email.