pub struct GoogleCloudChannelV1ListChannelPartnerLinksResponse {
pub channel_partner_links: Option<Vec<GoogleCloudChannelV1ChannelPartnerLink>>,
pub next_page_token: Option<String>,
}Expand description
Response message for CloudChannelService.ListChannelPartnerLinks.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- channel partner links list accounts (response)
Fields
channel_partner_links: Option<Vec<GoogleCloudChannelV1ChannelPartnerLink>>The Channel partner links for a reseller.
next_page_token: Option<String>A token to retrieve the next page of results. Pass to ListChannelPartnerLinksRequest.page_token to obtain that page.