pub struct GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponse {
pub channel_partner_repricing_configs: Option<Vec<GoogleCloudChannelV1ChannelPartnerRepricingConfig>>,
pub next_page_token: Option<String>,
}Expand description
Response message for CloudChannelService.ListChannelPartnerRepricingConfigs.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
channel_partner_repricing_configs: Option<Vec<GoogleCloudChannelV1ChannelPartnerRepricingConfig>>The repricing configs for this channel partner.
next_page_token: Option<String>A token to retrieve the next page of results. Pass to ListChannelPartnerRepricingConfigsRequest.page_token to obtain that page.