pub struct GoogleCloudChannelV1ListOffersResponse {
pub next_page_token: Option<String>,
pub offers: Option<Vec<GoogleCloudChannelV1Offer>>,
}Expand description
Response message for ListOffers.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- offers list accounts (response)
Fields
next_page_token: Option<String>A token to retrieve the next page of results.
offers: Option<Vec<GoogleCloudChannelV1Offer>>The list of Offers requested. The pricing information for each Offer only includes the base price. Effective prices and discounts aren’t populated.