GoogleCloudChannelV1ListTransferableOffersRequest

Struct GoogleCloudChannelV1ListTransferableOffersRequest 

pub struct GoogleCloudChannelV1ListTransferableOffersRequest {
    pub billing_account: Option<String>,
    pub cloud_identity_id: Option<String>,
    pub customer_name: Option<String>,
    pub language_code: Option<String>,
    pub page_size: Option<i32>,
    pub page_token: Option<String>,
    pub sku: Option<String>,
}
Request message for CloudChannelService.ListTransferableOffers

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

billing_account: Option<String>

Optional. The Billing Account to look up Offers for. Format: accounts/{account_id}/billingAccounts/{billing_account_id}. This field is only relevant for multi-currency accounts. It should be left empty for single currency accounts.

cloud_identity_id: Option<String>

Customer’s Cloud Identity ID

customer_name: Option<String>

A reseller should create a customer and use the resource name of that customer here.

language_code: Option<String>

Optional. The BCP-47 language code. For example, “en-US”. The response will localize in the corresponding language code, if specified. The default value is “en-US”.

page_size: Option<i32>

Requested page size. Server might return fewer results than requested. If unspecified, returns at most 100 offers. The maximum value is 1000; the server will coerce values above 1000.

page_token: Option<String>

A token for a page of results other than the first page. Obtained using ListTransferableOffersResponse.next_page_token of the previous CloudChannelService.ListTransferableOffers call.

sku: Option<String>

Required. The SKU to look up Offers for.