pub struct GoogleCloudChannelV1ListTransferableOffersResponse {
pub next_page_token: Option<String>,
pub transferable_offers: Option<Vec<GoogleCloudChannelV1TransferableOffer>>,
}Expand description
Response message for CloudChannelService.ListTransferableOffers.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list transferable offers accounts (response)
Fields
next_page_token: Option<String>A token to retrieve the next page of results. Pass to ListTransferableOffersRequest.page_token to obtain that page.
transferable_offers: Option<Vec<GoogleCloudChannelV1TransferableOffer>>Information about Offers for a customer that can be used for transfer.