GoogleCloudChannelV1ListTransferableSkusRequest

Struct GoogleCloudChannelV1ListTransferableSkusRequest 

pub struct GoogleCloudChannelV1ListTransferableSkusRequest {
    pub auth_token: Option<String>,
    pub cloud_identity_id: Option<String>,
    pub customer_name: Option<String>,
    pub language_code: Option<String>,
    pub page_size: Option<i32>,
    pub page_token: Option<String>,
}
Request message for CloudChannelService.ListTransferableSkus

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

auth_token: Option<String>

Optional. The super admin of the resold customer generates this token to authorize a reseller to access their Cloud Identity and purchase entitlements on their behalf. You can omit this token after authorization. See https://support.google.com/a/answer/7643790 for more details.

cloud_identity_id: Option<String>

Customer’s Cloud Identity ID

customer_name: Option<String>

A reseller is required to create a customer and use the resource name of the created customer here. Customer_name uses the format: accounts/{account_id}/customers/{customer_id}

language_code: Option<String>

The BCP-47 language code. For example, “en-US”. The response will localize in the corresponding language code, if specified. The default value is “en-US”. Optional.

page_size: Option<i32>

The requested page size. Server might return fewer results than requested. If unspecified, returns at most 100 SKUs. The maximum value is 1000; the server will coerce values above 1000. Optional.

page_token: Option<String>

A token for a page of results other than the first page. Obtained using ListTransferableSkusResponse.next_page_token of the previous CloudChannelService.ListTransferableSkus call. Optional.