GoogleCloudChannelV1Offer

Struct GoogleCloudChannelV1Offer 

pub struct GoogleCloudChannelV1Offer {
    pub constraints: Option<GoogleCloudChannelV1Constraints>,
    pub deal_code: Option<String>,
    pub end_time: Option<DateTime<Utc>>,
    pub marketing_info: Option<GoogleCloudChannelV1MarketingInfo>,
    pub name: Option<String>,
    pub parameter_definitions: Option<Vec<GoogleCloudChannelV1ParameterDefinition>>,
    pub plan: Option<GoogleCloudChannelV1Plan>,
    pub price_by_resources: Option<Vec<GoogleCloudChannelV1PriceByResource>>,
    pub sku: Option<GoogleCloudChannelV1Sku>,
    pub start_time: Option<DateTime<Utc>>,
}
Represents an offer made to resellers for purchase. An offer is associated with a Sku, has a plan for payment, a price, and defines the constraints for buying.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

constraints: Option<GoogleCloudChannelV1Constraints>

Constraints on transacting the Offer.

deal_code: Option<String>

The deal code of the offer to get a special promotion or discount.

end_time: Option<DateTime<Utc>>

Output only. End of the Offer validity time.

marketing_info: Option<GoogleCloudChannelV1MarketingInfo>

Marketing information for the Offer.

name: Option<String>

Resource Name of the Offer. Format: accounts/{account_id}/offers/{offer_id}

parameter_definitions: Option<Vec<GoogleCloudChannelV1ParameterDefinition>>

Parameters required to use current Offer to purchase.

plan: Option<GoogleCloudChannelV1Plan>

Describes the payment plan for the Offer.

price_by_resources: Option<Vec<GoogleCloudChannelV1PriceByResource>>

Price for each monetizable resource type.

sku: Option<GoogleCloudChannelV1Sku>

SKU the offer is associated with.

start_time: Option<DateTime<Utc>>

Start of the Offer validity time.