pub struct GoogleCloudChannelV1Parameter {
pub editable: Option<bool>,
pub name: Option<String>,
pub value: Option<GoogleCloudChannelV1Value>,
}Expand description
Definition for extended entitlement parameters.
This type is not used in any activity, and only used as part of another schema.
Fields
editable: Option<bool>Output only. Specifies whether this parameter is allowed to be changed. For example, for a Google Workspace Business Starter entitlement in commitment plan, num_units is editable when entitlement is active.
name: Option<String>Name of the parameter.
value: Option<GoogleCloudChannelV1Value>Value of the parameter.