GoogleCloudChannelV1Plan

Struct GoogleCloudChannelV1Plan 

pub struct GoogleCloudChannelV1Plan {
    pub billing_account: Option<String>,
    pub payment_cycle: Option<GoogleCloudChannelV1Period>,
    pub payment_plan: Option<String>,
    pub payment_type: Option<String>,
    pub trial_period: Option<GoogleCloudChannelV1Period>,
}
The payment plan for the Offer. Describes how to make a payment.

This type is not used in any activity, and only used as part of another schema.

Fields

billing_account: Option<String>

Reseller Billing account to charge after an offer transaction. Only present for Google Cloud offers.

payment_cycle: Option<GoogleCloudChannelV1Period>

Describes how frequently the reseller will be billed, such as once per month.

payment_plan: Option<String>

Describes how a reseller will be billed.

payment_type: Option<String>

Specifies when the payment needs to happen.

trial_period: Option<GoogleCloudChannelV1Period>

Present for Offers with a trial period. For trial-only Offers, a paid service needs to start before the trial period ends for continued service. For Regular Offers with a trial period, the regular pricing goes into effect when trial period ends, or if paid service is started before the end of the trial period.