pub struct GoogleCloudChannelV1Price {
pub base_price: Option<GoogleTypeMoney>,
pub discount: Option<f64>,
pub discount_components: Option<Vec<GoogleCloudChannelV1DiscountComponent>>,
pub effective_price: Option<GoogleTypeMoney>,
pub external_price_uri: Option<String>,
pub price_period: Option<GoogleCloudChannelV1Period>,
}Expand description
Represents the price of the Offer.
This type is not used in any activity, and only used as part of another schema.
Fields
base_price: Option<GoogleTypeMoney>Base price.
discount: Option<f64>Discount percentage, represented as decimal. For example, a 20% discount will be represent as 0.2.
discount_components: Option<Vec<GoogleCloudChannelV1DiscountComponent>>Breakdown of the discount into its components. This will be empty if there is no discount present.
effective_price: Option<GoogleTypeMoney>Effective Price after applying the discounts.
external_price_uri: Option<String>Link to external price list, such as link to Google Voice rate card.
price_period: Option<GoogleCloudChannelV1Period>The time period with respect to which base and effective prices are defined. Example: 1 month, 6 months, 1 year, etc.