pub struct GoogleCloudChannelV1PurchasableOffer {
pub offer: Option<GoogleCloudChannelV1Offer>,
pub price_reference_id: Option<String>,
}Expand description
Offer that you can purchase for a customer. This is used in the ListPurchasableOffer API response.
This type is not used in any activity, and only used as part of another schema.
Fields
offer: Option<GoogleCloudChannelV1Offer>Offer.
price_reference_id: Option<String>Optional. Price reference ID for the offer. Only for offers that require additional price information. Used to guarantee that the pricing is consistent between quoting the offer and placing the order.