pub struct GoogleCloudChannelV1RepricingCondition {
pub sku_group_condition: Option<GoogleCloudChannelV1SkuGroupCondition>,
}Expand description
Represents the various repricing conditions you can use for a conditional override.
This type is not used in any activity, and only used as part of another schema.
Fields
sku_group_condition: Option<GoogleCloudChannelV1SkuGroupCondition>SKU Group condition for override.