pub struct GoogleCloudChannelV1UnregisterSubscriberRequest {
pub account: Option<String>,
pub integrator: Option<String>,
pub service_account: Option<String>,
}Expand description
Request Message for UnregisterSubscriber.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- unregister accounts (request)
- unregister subscriber integrators (request)
Fields
account: Option<String>Optional. Resource name of the account. Required if integrator is not provided. Otherwise, leave this field empty/unset.
integrator: Option<String>Optional. Resource name of the integrator. Required if account is not provided. Otherwise, leave this field empty/unset.
service_account: Option<String>Required. Service account to unregister from subscriber access to the topic.