pub struct GoogleCloudChannelV1UnregisterSubscriberResponse {
pub topic: Option<String>,
}Expand description
Response Message for UnregisterSubscriber.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- unregister accounts (response)
- unregister subscriber integrators (response)
Fields
topic: Option<String>Name of the topic the service account subscriber access was removed from.